@@ -46,6 +46,10 @@
 #include "AuthConfigFactory.h"
 #include "AuthConfig.h"
 #include "DownloadContext.h"
+#include "RequestGroupMan.h"
+#include "ServerStatMan.h"
+#include "FileAllocationEntry.h"
+#include "CheckIntegrityEntry.h"
 
 namespace aria2 {
 
@@ -59,38 +63,39 @@ AbstractProxyRequestCommand::AbstractProxyRequestCommand
  const SocketHandle& s)
   :
   AbstractCommand(cuid, req, fileEntry, requestGroup, e, s),
-  _proxyRequest(proxyRequest),
-  httpConnection(new HttpConnection(cuid, s, getOption().get()))
+  proxyRequest_(proxyRequest),
+  httpConnection_(new HttpConnection(cuid, s))
 {
   setTimeout(getOption()->getAsInt(PREF_CONNECT_TIMEOUT));
   disableReadCheckSocket();
-  setWriteCheckSocket(socket);
+  setWriteCheckSocket(getSocket());
 }
 
 AbstractProxyRequestCommand::~AbstractProxyRequestCommand() {}
 
 bool AbstractProxyRequestCommand::executeInternal() {
   //socket->setBlockingMode();
-  if(httpConnection->sendBufferIsEmpty()) {
+  if(httpConnection_->sendBufferIsEmpty()) {
     if(!checkIfConnectionEstablished
-       (socket, _connectedHostname, _connectedAddr, _connectedPort)) {
+       (getSocket(), getRequest()->getConnectedHostname(),
+        getRequest()->getConnectedAddr(), getRequest()->getConnectedPort())) {
       return true;
     }
     SharedHandle<HttpRequest> httpRequest(new HttpRequest());
     httpRequest->setUserAgent(getOption()->get(PREF_USER_AGENT));
-    httpRequest->setRequest(req);
-    httpRequest->setProxyRequest(_proxyRequest);
+    httpRequest->setRequest(getRequest());
+    httpRequest->setProxyRequest(proxyRequest_);
 
-    httpConnection->sendProxyRequest(httpRequest);
+    httpConnection_->sendProxyRequest(httpRequest);
   } else {
-    httpConnection->sendPendingData();
+    httpConnection_->sendPendingData();
   }
-  if(httpConnection->sendBufferIsEmpty()) {
-    e->commands.push_back(getNextCommand());
+  if(httpConnection_->sendBufferIsEmpty()) {
+    getDownloadEngine()->addCommand(getNextCommand());
     return true;
   } else {
-    setWriteCheckSocket(socket);
-    e->commands.push_back(this);
+    setWriteCheckSocket(getSocket());
+    getDownloadEngine()->addCommand(this);
     return false;
   }
 }
