@@ -112,8 +112,9 @@ void AdaptiveURISelector::mayRetryWithIncreasedTimeout(FileEntry* fileEntry)
     for(std::deque<std::string>::const_iterator i = uris.begin(),
           eoi = uris.end(); i != eoi; ++i) {
       logger_->debug("AdaptiveURISelector: will retry server with increased"
-                     " timeout (%d s): %s",
-                     requestGroup_->getTimeout(), (*i).c_str());
+                     " timeout (%ld s): %s",
+                     static_cast<long int>(requestGroup_->getTimeout()),
+                     (*i).c_str());
     }
   }
 }
@@ -240,11 +241,13 @@ void AdaptiveURISelector::adjustLowestSpeedLimit
   }
 }
 
-static unsigned int getUriMaxSpeed(SharedHandle<ServerStat> ss)
+namespace {
+unsigned int getUriMaxSpeed(SharedHandle<ServerStat> ss)
 {
   return std::max(ss->getSingleConnectionAvgSpeed(),
                   ss->getMultiConnectionAvgSpeed());
 }
+} // namespace
 
 unsigned int AdaptiveURISelector::getMaxDownloadSpeed
 (const std::deque<std::string>& uris) const
