@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,8 +38,8 @@
 
 #include "A2STR.h"
 #include "SimpleRandomizer.h"
-#include "bencode.h"
 #include "util.h"
+#include "a2algo.h"
 
 namespace aria2 {
 
@@ -49,111 +49,102 @@ const std::string AnnounceList::STOPPED("stopped");
 
 const std::string AnnounceList::COMPLETED("completed");
 
-AnnounceList::AnnounceList(const BDE& announceList):
-  currentTrackerInitialized(false) {
+AnnounceList::AnnounceList
+(const std::vector<std::vector<std::string> >& announceList):
+  currentTrackerInitialized_(false) {
   reconfigure(announceList);
 }
 
-AnnounceList::AnnounceList(const AnnounceTiers& announceTiers):
-  tiers(announceTiers), currentTrackerInitialized(false)  {
+AnnounceList::AnnounceList
+(const std::deque<SharedHandle<AnnounceTier> >& announceTiers):
+  tiers_(announceTiers), currentTrackerInitialized_(false)  {
   resetIterator();
 }
 
-void AnnounceList::reconfigure(const BDE& announceList)
+void AnnounceList::reconfigure
+(const std::vector<std::vector<std::string> >& announceList)
 {
-  if(announceList.isList()) {
-    for(BDE::List::const_iterator itr = announceList.listBegin();
-	itr != announceList.listEnd(); ++itr) {
-      const BDE& elemList = *itr;
-      if(!elemList.isList()) {
-	continue;
-      }
-      std::deque<std::string> urls;
-      for(BDE::List::const_iterator elemItr = elemList.listBegin();
-	  elemItr != elemList.listEnd(); ++elemItr) {
-	const BDE& data = *elemItr;
-	if(data.isString()) {
-	  urls.push_back(data.s());
-	}
-      }
-      if(!urls.empty()) {
-	AnnounceTierHandle tier(new AnnounceTier(urls));
-	tiers.push_back(tier);
-      }
+  for(std::vector<std::vector<std::string> >::const_iterator itr =
+        announceList.begin(), eoi = announceList.end(); itr != eoi; ++itr) {
+    if((*itr).empty()) {
+      continue;
     }
-    resetIterator();
+    std::deque<std::string> urls((*itr).begin(), (*itr).end());
+    SharedHandle<AnnounceTier> tier(new AnnounceTier(urls));
+    tiers_.push_back(tier);
   }
+  resetIterator();
 }
 
 void AnnounceList::reconfigure(const std::string& url) {
   std::deque<std::string> urls;
   urls.push_back(url);
-  tiers.push_back(AnnounceTierHandle(new AnnounceTier(urls)));
+  tiers_.push_back(SharedHandle<AnnounceTier>(new AnnounceTier(urls)));
   resetIterator();
 }
 
 void AnnounceList::resetIterator() {
-  currentTier = tiers.begin();
-  if(currentTier != tiers.end() && (*currentTier)->urls.size()) {
-    currentTracker = (*currentTier)->urls.begin();
-    currentTrackerInitialized = true;
+  currentTier_ = tiers_.begin();
+  if(currentTier_ != tiers_.end() && (*currentTier_)->urls.size()) {
+    currentTracker_ = (*currentTier_)->urls.begin();
+    currentTrackerInitialized_ = true;
   } else {
-    currentTrackerInitialized = false;
+    currentTrackerInitialized_ = false;
   }
 }
 
 std::string AnnounceList::getAnnounce() const {
-  if(currentTrackerInitialized) {
-    return *currentTracker;
+  if(currentTrackerInitialized_) {
+    return *currentTracker_;
   } else {
     return A2STR::NIL;
   }
 }
 
 void AnnounceList::announceSuccess() {
-  if(currentTrackerInitialized) {
-    (*currentTier)->nextEvent();
-    std::string url = *currentTracker;
-    (*currentTier)->urls.erase(currentTracker);
-    (*currentTier)->urls.push_front(url);
-    currentTier = tiers.begin();
-    currentTracker = (*currentTier)->urls.begin();
+  if(currentTrackerInitialized_) {
+    (*currentTier_)->nextEvent();
+    std::string url = *currentTracker_;
+    (*currentTier_)->urls.erase(currentTracker_);
+    (*currentTier_)->urls.push_front(url);
+    currentTier_ = tiers_.begin();
+    currentTracker_ = (*currentTier_)->urls.begin();
   }
 }
 
 void AnnounceList::announceFailure() {
-  if(currentTrackerInitialized) {
-    ++currentTracker;
-    if(currentTracker == (*currentTier)->urls.end()) {
+  if(currentTrackerInitialized_) {
+    ++currentTracker_;
+    if(currentTracker_ == (*currentTier_)->urls.end()) {
       // force next event
-      (*currentTier)->nextEventIfAfterStarted();
-      ++currentTier;
-      if(currentTier == tiers.end()) {
-	currentTrackerInitialized = false;
+      (*currentTier_)->nextEventIfAfterStarted();
+      ++currentTier_;
+      if(currentTier_ == tiers_.end()) {
+        currentTrackerInitialized_ = false;
       } else {
-	currentTracker = (*currentTier)->urls.begin();
+        currentTracker_ = (*currentTier_)->urls.begin();
       }
     }
   }
 }
 
 AnnounceTier::AnnounceEvent AnnounceList::getEvent() const {
-  if(currentTrackerInitialized) {
-    return (*currentTier)->event;
+  if(currentTrackerInitialized_) {
+    return (*currentTier_)->event;
   } else {
     return AnnounceTier::STARTED;
   }
 }
 
 void AnnounceList::setEvent(AnnounceTier::AnnounceEvent event) {
-  if(currentTrackerInitialized) {
-    (*currentTier)->event = event;
+  if(currentTrackerInitialized_) {
+    (*currentTier_)->event = event;
   }
 }
 
 std::string AnnounceList::getEventString() const {
-  if(currentTrackerInitialized) {
-    switch((*currentTier)->event) {
+  if(currentTrackerInitialized_) {
+    switch((*currentTier_)->event) {
     case AnnounceTier::STARTED:
     case AnnounceTier::STARTED_AFTER_COMPLETION:
       return STARTED;
@@ -169,9 +160,10 @@ std::string AnnounceList::getEventString() const {
   }
 }
 
+namespace {
 class FindStoppedAllowedTier {
 public:
-  bool operator()(const AnnounceTierHandle& tier) const {
+  bool operator()(const SharedHandle<AnnounceTier>& tier) const {
     switch(tier->event) {
     case AnnounceTier::DOWNLOADING:
     case AnnounceTier::STOPPED:
@@ -183,10 +175,12 @@ public:
     }
   }
 };
+} // namespace
 
+namespace {
 class FindCompletedAllowedTier {
 public:
-  bool operator()(const AnnounceTierHandle& tier) const {
+  bool operator()(const SharedHandle<AnnounceTier>& tier) const {
     switch(tier->event) {
     case AnnounceTier::DOWNLOADING:
     case AnnounceTier::COMPLETED:
@@ -196,59 +190,52 @@ public:
     }
   }
 };
+} // namespace
 
 size_t AnnounceList::countStoppedAllowedTier() const {
-  return count_if(tiers.begin(), tiers.end(), FindStoppedAllowedTier());
+  return count_if(tiers_.begin(), tiers_.end(), FindStoppedAllowedTier());
 }
 
 size_t AnnounceList::countCompletedAllowedTier() const {
-  return count_if(tiers.begin(), tiers.end(), FindCompletedAllowedTier());
+  return count_if(tiers_.begin(), tiers_.end(), FindCompletedAllowedTier());
 }
 
-void AnnounceList::setCurrentTier(const AnnounceTiers::iterator& itr) {
-  if(itr != tiers.end()) {
-    currentTier = itr;
-    currentTracker = (*currentTier)->urls.begin();
+void AnnounceList::setCurrentTier
+(const std::deque<SharedHandle<AnnounceTier> >::iterator& itr) {
+  if(itr != tiers_.end()) {
+    currentTier_ = itr;
+    currentTracker_ = (*currentTier_)->urls.begin();
   }
 }
 
-template<class InputIterator, class Predicate>
-InputIterator
-find_wrap_if(InputIterator first, InputIterator last,
-	     InputIterator current, Predicate pred) {
-  InputIterator itr = std::find_if(current, last, pred);
-  if(itr == last) {
-    itr = std::find_if(first, current, pred);
-  }
-  return itr;
-}
-
 void AnnounceList::moveToStoppedAllowedTier() {
-  AnnounceTiers::iterator itr = find_wrap_if(tiers.begin(), tiers.end(),
-					     currentTier,
-					     FindStoppedAllowedTier());
+  std::deque<SharedHandle<AnnounceTier> >::iterator itr =
+    find_wrap_if(tiers_.begin(), tiers_.end(),
+                 currentTier_,
+                 FindStoppedAllowedTier());
   setCurrentTier(itr);
 }
 
 void AnnounceList::moveToCompletedAllowedTier() {
-  AnnounceTiers::iterator itr = find_wrap_if(tiers.begin(), tiers.end(),
-					     currentTier,
-					     FindCompletedAllowedTier());
+  std::deque<SharedHandle<AnnounceTier> >::iterator itr =
+    find_wrap_if(tiers_.begin(), tiers_.end(),
+                 currentTier_,
+                 FindCompletedAllowedTier());
   setCurrentTier(itr);
 }
 
 void AnnounceList::shuffle() {
-  for(AnnounceTiers::iterator itr = tiers.begin();
-      itr != tiers.end(); ++itr) {
+  for(std::deque<SharedHandle<AnnounceTier> >::const_iterator itr =
+        tiers_.begin(), eoi = tiers_.end(); itr != eoi; ++itr) {
     std::deque<std::string>& urls = (*itr)->urls;
     std::random_shuffle(urls.begin(), urls.end(),
-			*(SimpleRandomizer::getInstance().get()));
+                        *(SimpleRandomizer::getInstance().get()));
   }
 }
 
 bool AnnounceList::allTiersFailed() const
 {
-  return currentTier == tiers.end();
+  return currentTier_ == tiers_.end();
 }
 
 void AnnounceList::resetTier()
@@ -258,8 +245,8 @@ void AnnounceList::resetTier()
 
 bool AnnounceList::currentTierAcceptsStoppedEvent() const
 {
-  if(currentTrackerInitialized) {
-    return FindStoppedAllowedTier()(*currentTier);
+  if(currentTrackerInitialized_) {
+    return FindStoppedAllowedTier()(*currentTier_);
   } else {
     return false;
   }
@@ -267,8 +254,8 @@ bool AnnounceList::currentTierAcceptsStoppedEvent() const
 
 bool AnnounceList::currentTierAcceptsCompletedEvent() const
 {
-  if(currentTrackerInitialized) {
-    return FindCompletedAllowedTier()(*currentTier);
+  if(currentTrackerInitialized_) {
+    return FindCompletedAllowedTier()(*currentTier_);
   } else {
     return false;
   }
