@@ -59,8 +59,9 @@ BtDependency::BtDependency(const WeakHandle<RequestGroup>& dependant,
 
 BtDependency::~BtDependency() {}
 
-static void copyValues(const SharedHandle<FileEntry>& d,
-                       const SharedHandle<FileEntry>& s)
+namespace {
+void copyValues(const SharedHandle<FileEntry>& d,
+                const SharedHandle<FileEntry>& s)
 {
   d->setRequested(true);
   d->setPath(s->getPath());
@@ -69,6 +70,7 @@ static void copyValues(const SharedHandle<FileEntry>& d,
   d->setMaxConnectionPerServer(s->getMaxConnectionPerServer());
   d->setUniqueProtocol(s->isUniqueProtocol());
 }
+} // namespace
 
 bool BtDependency::resolve()
 {
@@ -88,9 +90,13 @@ bool BtDependency::resolve()
           bittorrent::getTorrentAttrs(dependee->getDownloadContext());
         bittorrent::loadFromMemory
           (bittorrent::metadata2Torrent(content, attrs), context, "default");
+        // We don't call bittorrent::adjustAnnounceUri() because it
+        // has already been called with attrs.
       } else {
         bittorrent::loadFromMemory
           (content, context, File(dependee->getFirstFilePath()).getBasename());
+        bittorrent::adjustAnnounceUri(bittorrent::getTorrentAttrs(context),
+                                      dependant_->getOption());
       }
       const std::vector<SharedHandle<FileEntry> >& fileEntries =
         context->getFileEntries();
