@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DOWNLOAD_CONTEXT_H_
-#define _D_DOWNLOAD_CONTEXT_H_
+#ifndef D_DOWNLOAD_CONTEXT_H
+#define D_DOWNLOAD_CONTEXT_H
 
 #include "common.h"
 
@@ -45,9 +45,10 @@
 #include "Signature.h"
 #include "TimerA2.h"
 #include "A2STR.h"
-#include "BDE.h"
+#include "ValueBase.h"
 #include "IntSequence.h"
 #include "FileEntry.h"
+#include "TorrentAttribute.h"
 
 namespace aria2 {
 
@@ -56,35 +57,35 @@ class RequestGroup;
 class DownloadContext
 {
 private:
-  std::vector<SharedHandle<FileEntry> > _fileEntries;
+  std::vector<SharedHandle<FileEntry> > fileEntries_;
 
-  std::string _dir;
+  std::string dir_;
 
-  std::vector<std::string> _pieceHashes;
+  std::vector<std::string> pieceHashes_;
 
-  size_t _pieceLength;
+  size_t pieceLength_;
 
-  std::string _pieceHashAlgo;
+  std::string pieceHashAlgo_;
 
-  std::string _checksum;
+  std::string checksum_;
 
-  std::string _checksumHashAlgo;
+  std::string checksumHashAlgo_;
 
-  std::string _basePath;
+  bool checksumVerified_;
 
-  bool _knowsTotalLength;
+  std::string basePath_;
 
-  RequestGroup* _ownerRequestGroup;
+  bool knowsTotalLength_;
+
+  RequestGroup* ownerRequestGroup_;
   
-  BDE _attrs;
+  std::map<std::string, SharedHandle<ContextAttribute> > attrs_;
 
-  Timer _downloadStartTime;
+  Timer downloadStartTime_;
 
-  Timer _downloadStopTime;
+  Timer downloadStopTime_;
 
-  SharedHandle<Signature> _signature;
-
-  void ensureAttrs();
+  SharedHandle<Signature> signature_;
 public:
   DownloadContext();
 
@@ -96,8 +97,8 @@ public:
 
   const std::string& getPieceHash(size_t index) const
   {
-    if(index < _pieceHashes.size()) {
-      return _pieceHashes[index];
+    if(index < pieceHashes_.size()) {
+      return pieceHashes_[index];
     } else {
       return A2STR::NIL;
     }
@@ -105,114 +106,91 @@ public:
   
   const std::vector<std::string>& getPieceHashes() const
   {
-    return _pieceHashes;
+    return pieceHashes_;
   }
 
   template<typename InputIterator>
   void setPieceHashes(InputIterator first, InputIterator last)
   {
-    _pieceHashes.assign(first, last);
+    pieceHashes_.assign(first, last);
   }
 
-  uint64_t getTotalLength() const
-  {
-    if(_fileEntries.empty()) {
-      return 0;
-    } else {
-      return _fileEntries.back()->getLastOffset();
-    }
-  }
+  uint64_t getTotalLength() const;
 
-  bool knowsTotalLength() const { return _knowsTotalLength; }
+  bool knowsTotalLength() const { return knowsTotalLength_; }
 
-  void markTotalLengthIsUnknown() { _knowsTotalLength = false; }
+  void markTotalLengthIsUnknown() { knowsTotalLength_ = false; }
 
-  void markTotalLengthIsKnown() { _knowsTotalLength = true; }
+  void markTotalLengthIsKnown() { knowsTotalLength_ = true; }
 
   const std::vector<SharedHandle<FileEntry> >& getFileEntries() const
   {
-    return _fileEntries;
+    return fileEntries_;
   }
 
   const SharedHandle<FileEntry>& getFirstFileEntry() const
   {
-    assert(!_fileEntries.empty());
-    return _fileEntries[0];
+    assert(!fileEntries_.empty());
+    return fileEntries_[0];
   }
 
   template<typename InputIterator>
   void setFileEntries(InputIterator first, InputIterator last)
   {
-    _fileEntries.assign(first, last);
+    fileEntries_.assign(first, last);
   }
 
-  size_t getPieceLength() const { return _pieceLength; }
+  size_t getPieceLength() const { return pieceLength_; }
 
-  void setPieceLength(size_t length) { _pieceLength = length; }
+  void setPieceLength(size_t length) { pieceLength_ = length; }
 
-  size_t getNumPieces() const
-  {
-    if(_pieceLength == 0) {
-      return 0;
-    } else {
-      assert(!_fileEntries.empty());
-      return (_fileEntries.back()->getLastOffset()+_pieceLength-1)/_pieceLength;
-    }
-  }
+  size_t getNumPieces() const;
 
-  const std::string& getPieceHashAlgo() const { return _pieceHashAlgo; }
+  const std::string& getPieceHashAlgo() const { return pieceHashAlgo_; }
 
   void setPieceHashAlgo(const std::string& algo)
   {
-    _pieceHashAlgo = algo;
+    pieceHashAlgo_ = algo;
   }
 
-  const std::string& getChecksum() const { return _checksum; }
+  const std::string& getChecksum() const { return checksum_; }
 
   void setChecksum(const std::string& checksum)
   {
-    _checksum = checksum;
+    checksum_ = checksum;
   }
 
-  const std::string& getChecksumHashAlgo() const { return _checksumHashAlgo; }
+  const std::string& getChecksumHashAlgo() const { return checksumHashAlgo_; }
 
   void setChecksumHashAlgo(const std::string& algo)
   {
-    _checksumHashAlgo = algo;
+    checksumHashAlgo_ = algo;
   }
 
   // The representative path name for this context. It is used as a
-  // part of .aria2 control file. If _basePath is set, returns
-  // _basePath. Otherwise, the first FileEntry's getFilePath() is
+  // part of .aria2 control file. If basePath_ is set, returns
+  // basePath_. Otherwise, the first FileEntry's getFilePath() is
   // returned.
-  const std::string& getBasePath() const
-  {
-    if(_basePath.empty()) {
-      assert(!_fileEntries.empty());
-      return getFirstFileEntry()->getPath();
-    } else {
-      return _basePath;
-    }
-  }
+  const std::string& getBasePath() const;
 
-  void setBasePath(const std::string& basePath) { _basePath = basePath; }
+  void setBasePath(const std::string& basePath) { basePath_ = basePath; }
 
-  const std::string& getDir() const { return _dir; }
+  const std::string& getDir() const { return dir_; }
 
-  void setDir(const std::string& dir) { _dir = dir; }
+  void setDir(const std::string& dir) { dir_ = dir; }
 
-  const SharedHandle<Signature>& getSignature() const { return _signature; }
+  const SharedHandle<Signature>& getSignature() const { return signature_; }
 
   void setSignature(const SharedHandle<Signature>& signature)
   {
-    _signature = signature;
+    signature_ = signature;
   }
 
-  RequestGroup* getOwnerRequestGroup() { return _ownerRequestGroup; }
+  RequestGroup* getOwnerRequestGroup() { return ownerRequestGroup_; }
 
   void setOwnerRequestGroup(RequestGroup* owner)
   {
-    _ownerRequestGroup = owner;
+    ownerRequestGroup_ = owner;
   }
 
   void setFileFilter(IntSequence seq);
@@ -224,9 +202,25 @@ public:
   // this function.
   void setFilePathWithIndex(size_t index, const std::string& path);
 
-  void setAttribute(const std::string& key, const BDE& value);
+  // Returns true if hash check(whole file hash, not piece hash) is
+  // need to be done
+  bool isChecksumVerificationNeeded() const;
 
-  BDE& getAttribute(const std::string& key);
+  // Returns true if whole hash(not piece hash) is available.
+  bool isChecksumVerificationAvailable() const;
+
+  // Returns true if piece hash(not whole file hash) is available.
+  bool isPieceHashVerificationAvailable() const;
+
+  void setChecksumVerified(bool f)
+  {
+    checksumVerified_ = f;
+  }
+
+  void setAttribute
+  (const std::string& key, const SharedHandle<ContextAttribute>& value);
+
+  const SharedHandle<ContextAttribute>& getAttribute(const std::string& key);
 
   bool hasAttribute(const std::string& key) const;
 
@@ -236,7 +230,7 @@ public:
 
   const Timer& getDownloadStopTime() const
   {
-    return _downloadStopTime;
+    return downloadStopTime_;
   }
 
   int64_t calculateSessionTime() const;
@@ -250,4 +244,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_DOWNLOAD_CONTEXT_H_
+#endif // D_DOWNLOAD_CONTEXT_H
