@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DOWNLOAD_RESULT_H_
-#define _D_DOWNLOAD_RESULT_H_
+#ifndef D_DOWNLOAD_RESULT_H
+#define D_DOWNLOAD_RESULT_H
 
 #include "common.h"
 
@@ -44,15 +44,17 @@
 
 #include "SharedHandle.h"
 #include "DownloadResultCode.h"
+#include "RequestGroup.h"
+#include "Option.h"
+#include "MetadataInfo.h"
 
 namespace aria2 {
 
 class FileEntry;
 
-class DownloadResult
+struct DownloadResult
 {
-public:
-  int32_t gid;
+  gid_t gid;
  
   std::vector<SharedHandle<FileEntry> > fileEntries;
 
@@ -67,32 +69,35 @@ public:
 
   // This field contains GIDs. See comment in
   // RequestGroup.cc::_followedByGIDs.
-  std::vector<int32_t> followedBy;
+  std::vector<gid_t> followedBy;
 
   // This field contains GID. See comment in
   // RequestGroup.cc::_belongsToGID.
-  int32_t belongsTo;
+  gid_t belongsTo;
 
-  DownloadResult(int32_t gid,
-		 const std::vector<SharedHandle<FileEntry> >& fileEntries,
-		 bool inMemoryDownload,
-		 uint64_t sessionDownloadLength,
-		 int64_t sessionTime,
-		 downloadresultcode::RESULT result,
-		 const std::vector<int32_t> followedBy,
-		 int32_t belongsTo):
-    gid(gid),
-    fileEntries(fileEntries),
-    inMemoryDownload(inMemoryDownload),
-    sessionDownloadLength(sessionDownloadLength),
-    sessionTime(sessionTime),
-    result(result),
-    followedBy(followedBy),
-    belongsTo(belongsTo) {}
+  SharedHandle<Option> option;
+
+  SharedHandle<MetadataInfo> metadataInfo;
+
+  uint64_t totalLength;
+
+  uint64_t completedLength;
+
+  uint64_t uploadLength;
+
+  std::string bitfieldStr;
+
+  std::string infoHashStr;
+
+  size_t pieceLength;
+
+  size_t numPieces;
+
+  std::string dir;
 };
 
 typedef SharedHandle<DownloadResult> DownloadResultHandle;
 
 } // namespace aria2
 
-#endif // _D_DOWNLOAD_RESULT_H_
+#endif // D_DOWNLOAD_RESULT_H
