@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_EXTENSION_MESSAGE_REGISTRY_H_
-#define _D_EXTENSION_MESSAGE_REGISTRY_H_
+#ifndef D_EXTENSION_MESSAGE_REGISTRY_H
+#define D_EXTENSION_MESSAGE_REGISTRY_H
 
 #include "common.h"
 
@@ -46,24 +46,24 @@ namespace aria2 {
 
 class ExtensionMessageRegistry {
 private:
-  Extensions _extensions;
+  Extensions extensions_;
 public:
   ExtensionMessageRegistry()
   {
-    _extensions["ut_pex"] = 8;
+    extensions_["ut_pex"] = 8;
     // http://www.bittorrent.org/beps/bep_0009.html
-    _extensions["ut_metadata"] = 9;
+    extensions_["ut_metadata"] = 9;
   }
 
   const Extensions& getExtensions() const
   {
-    return _extensions;
+    return extensions_;
   }
 
   uint8_t getExtensionMessageID(const std::string& name) const
   {
-    Extensions::const_iterator itr = _extensions.find(name);
-    if(itr == _extensions.end()) {
+    Extensions::const_iterator itr = extensions_.find(name);
+    if(itr == extensions_.end()) {
       return 0;
     } else {
       return (*itr).second;
@@ -72,8 +72,8 @@ public:
 
   const std::string& getExtensionName(uint8_t id) const
   {
-    for(Extensions::const_iterator itr = _extensions.begin(),
-          eoi = _extensions.end(); itr != eoi; ++itr) {
+    for(Extensions::const_iterator itr = extensions_.begin(),
+          eoi = extensions_.end(); itr != eoi; ++itr) {
       const Extensions::value_type& p = *itr;
       if(p.second == id) {
         return p.first;
@@ -84,10 +84,10 @@ public:
 
   void removeExtension(const std::string& name)
   {
-    _extensions.erase(name);
+    extensions_.erase(name);
   }
 };
 
 } // namespace aria2
 
-#endif // _D_EXTENSION_MESSAGE_REGISTRY_H_
+#endif // D_EXTENSION_MESSAGE_REGISTRY_H
