@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,14 +32,16 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_FEATURE_CONFIG_H_
-#define _D_FEATURE_CONFIG_H_
+#ifndef D_FEATURE_CONFIG_H
+#define D_FEATURE_CONFIG_H
 
 #include "common.h"
-#include "SharedHandle.h"
+
 #include <map>
 #include <string>
 
+#include "SharedHandle.h"
+
 namespace aria2 {
 
 typedef std::map<std::string, uint16_t> PortMap;
@@ -47,14 +49,14 @@ typedef std::map<std::string, bool> FeatureMap;
 
 class FeatureConfig {
 private:
-  static SharedHandle<FeatureConfig> _featureConfig;
+  static SharedHandle<FeatureConfig> featureConfig_;
 
-  PortMap _defaultPorts;
-  FeatureMap _features;
+  PortMap defaultPorts_;
+  FeatureMap features_;
 
   FeatureConfig();
 public:
-  static SharedHandle<FeatureConfig> getInstance();
+  static const SharedHandle<FeatureConfig>& getInstance();
 
   uint16_t getDefaultPort(const std::string& protocol) const;
 
@@ -64,7 +66,7 @@ public:
 
   const FeatureMap& getFeatures() const
   {
-    return _features;
+    return features_;
   }
 
   static const std::string FEATURE_HTTPS;
@@ -72,10 +74,11 @@ public:
   static const std::string FEATURE_METALINK;
   static const std::string FEATURE_MESSAGE_DIGEST;
   static const std::string FEATURE_ASYNC_DNS;
+  static const std::string FEATURE_XML_RPC;
   static const std::string FEATURE_GZIP;
   static const std::string FEATURE_FIREFOX3_COOKIE;
 };
 
 } // namespace aria2
 
-#endif // _D_FEATURE_CONFIG_H_
+#endif // D_FEATURE_CONFIG_H
