@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_HTTP_CONNECTION_H_
-#define _D_HTTP_CONNECTION_H_
+#ifndef D_HTTP_CONNECTION_H
+#define D_HTTP_CONNECTION_H
 
 #include "common.h"
 
@@ -42,6 +42,7 @@
 
 #include "SharedHandle.h"
 #include "SocketBuffer.h"
+#include "Command.h"
 
 namespace aria2 {
 
@@ -55,8 +56,8 @@ class SocketCore;
 
 class HttpRequestEntry {
 private:
-  SharedHandle<HttpRequest> _httpRequest;
-  SharedHandle<HttpHeaderProcessor> _proc;
+  SharedHandle<HttpRequest> httpRequest_;
+  SharedHandle<HttpHeaderProcessor> proc_;
 public:
   HttpRequestEntry(const SharedHandle<HttpRequest>& httpRequest);
 
@@ -64,12 +65,12 @@ public:
 
   const SharedHandle<HttpRequest>& getHttpRequest() const
   {
-    return _httpRequest;
+    return httpRequest_;
   }
 
   const SharedHandle<HttpHeaderProcessor>& getHttpHeaderProcessor() const
   {
-    return _proc;
+    return proc_;
   }
 };
 
@@ -78,19 +79,17 @@ typedef std::deque<HttpRequestEntryHandle> HttpRequestEntries;
 
 class HttpConnection {
 private:
-  int32_t cuid;
-  SharedHandle<SocketCore> socket;
-  SocketBuffer _socketBuffer;
-  const Option* option;
-  Logger* logger;
+  cuid_t cuid_;
+  SharedHandle<SocketCore> socket_;
+  SocketBuffer socketBuffer_;
+  const Option* option_;
+  Logger* logger_;
 
-  HttpRequestEntries outstandingHttpRequests;
+  HttpRequestEntries outstandingHttpRequests_;
 
   std::string eraseConfidentialInfo(const std::string& request);
 public:
-  HttpConnection(int32_t cuid,
-		 const SharedHandle<SocketCore>& socket,
-		 const Option* op);
+  HttpConnection(cuid_t cuid, const SharedHandle<SocketCore>& socket);
 
   /**
    * Sends Http request.
@@ -132,4 +131,4 @@ typedef SharedHandle<HttpConnection> HttpConnectionHandle;
 
 } // namespace aria2
 
-#endif // _D_HTTP_CONNECTION_H_
+#endif // D_HTTP_CONNECTION_H
