@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_HTTP_REQUEST_H_
-#define _D_HTTP_REQUEST_H_
+#ifndef D_HTTP_REQUEST_H
+#define D_HTTP_REQUEST_H
 
 #include "common.h"
 
@@ -87,6 +87,10 @@ private:
 
   bool acceptGzip_;
 
+  off_t endOffsetOverride_;
+
+  std::string ifModSinceHeader_;
+
   std::pair<std::string, std::string> getProxyAuthString() const;
 public:
   HttpRequest();
@@ -272,8 +276,23 @@ public:
   {
     return acceptGzip_;
   }
+
+  void setEndOffsetOverride(off_t offset)
+  {
+    endOffsetOverride_ = offset;
+  }
+
+  void setIfModifiedSinceHeader(const std::string& hd)
+  {
+    ifModSinceHeader_ = hd;
+  }
+
+  const std::string& getIfModifiedSinceHeader() const
+  {
+    return ifModSinceHeader_;
+  }
 };
 
 } // namespace aria2
 
-#endif // _D_HTTP_REQUEST_H_
+#endif // D_HTTP_REQUEST_H
