@@ -57,6 +57,9 @@
 #include "FileAllocationEntry.h"
 #include "CheckIntegrityEntry.h"
 #include "ServerStatMan.h"
+#include "PieceStorage.h"
+#include "DefaultBtProgressInfoFile.h"
+#include "Logger.h"
 
 namespace aria2 {
 
@@ -78,7 +81,8 @@ HttpRequestCommand::HttpRequestCommand
 
 HttpRequestCommand::~HttpRequestCommand() {}
 
-static SharedHandle<HttpRequest>
+namespace {
+SharedHandle<HttpRequest>
 createHttpRequest(const SharedHandle<Request>& req,
                   const SharedHandle<FileEntry>& fileEntry,
                   const SharedHandle<Segment>& segment,
@@ -87,7 +91,8 @@ createHttpRequest(const SharedHandle<Request>& req,
                   const RequestGroup* rg,
                   const SharedHandle<CookieStorage>& cookieStorage,
                   const SharedHandle<AuthConfigFactory>& authConfigFactory,
-                  const SharedHandle<Request>& proxyRequest)
+                  const SharedHandle<Request>& proxyRequest,
+                  off_t endOffset = 0)
 {
   SharedHandle<HttpRequest> httpRequest(new HttpRequest());
   httpRequest->setUserAgent(option->get(PREF_USER_AGENT));
@@ -110,8 +115,10 @@ createHttpRequest(const SharedHandle<Request>& req,
   } else {
     httpRequest->disableNoCache();
   }
+  httpRequest->setEndOffsetOverride(endOffset);
   return httpRequest;
 }
+} // namespace
 
 bool HttpRequestCommand::executeInternal() {
   //socket->setBlockingMode();
@@ -126,7 +133,8 @@ bool HttpRequestCommand::executeInternal() {
   }
   if(httpConnection_->sendBufferIsEmpty()) {
     if(!checkIfConnectionEstablished
-       (getSocket(), connectedHostname_, connectedAddr_, connectedPort_)) {
+       (getSocket(), getRequest()->getConnectedHostname(),
+        getRequest()->getConnectedAddr(), getRequest()->getConnectedPort())) {
       return true;
     }
 
@@ -141,6 +149,31 @@ bool HttpRequestCommand::executeInternal() {
                            getDownloadEngine()->getCookieStorage(),
                            getDownloadEngine()->getAuthConfigFactory(),
                            proxyRequest_));
+      if(getOption()->getAsBool(PREF_CONDITIONAL_GET) &&
+         (getRequest()->getProtocol() == Request::PROTO_HTTP ||
+          getRequest()->getProtocol() == Request::PROTO_HTTPS)) {
+        if(getFileEntry()->getPath().empty() &&
+           getRequest()->getFile().empty()) {
+          if(getLogger()->debug()) {
+            getLogger()->debug("conditional-get is disabled because file name"
+                               "is not available.");
+          }
+        } else {
+          if(getFileEntry()->getPath().empty()) {
+            getFileEntry()->setPath
+              (util::createSafePath
+               (getDownloadContext()->getDir(),
+                util::percentDecode(getRequest()->getFile())));
+          }
+          File ctrlfile(getFileEntry()->getPath()+
+                        DefaultBtProgressInfoFile::getSuffix());
+          File file(getFileEntry()->getPath());
+          if(!ctrlfile.exists() && file.exists()) {
+            httpRequest->setIfModifiedSinceHeader
+              (file.getModifiedTime().toHTTPDate());
+          }
+        }
+      }
       httpConnection_->sendRequest(httpRequest);
     } else {
       for(std::vector<SharedHandle<Segment> >::const_iterator itr =
@@ -148,6 +181,16 @@ bool HttpRequestCommand::executeInternal() {
           itr != eoi; ++itr) {
         const SharedHandle<Segment>& segment = *itr;
         if(!httpConnection_->isIssued(segment)) {
+          off_t endOffset = 0;
+          if(getRequestGroup()->getTotalLength() > 0 &&
+             !getPieceStorage().isNull()) {
+            size_t nextIndex =
+              getPieceStorage()->getNextUsedIndex(segment->getIndex());
+            endOffset = std::min
+              (static_cast<off_t>(getFileEntry()->getLength()),
+               getFileEntry()->gtoloff
+               (static_cast<off_t>(segment->getSegmentLength())*nextIndex));
+          }
           SharedHandle<HttpRequest> httpRequest
             (createHttpRequest(getRequest(),
                                getFileEntry(),
@@ -157,7 +200,8 @@ bool HttpRequestCommand::executeInternal() {
                                getRequestGroup(),
                                getDownloadEngine()->getCookieStorage(),
                                getDownloadEngine()->getAuthConfigFactory(),
-                               proxyRequest_));
+                               proxyRequest_,
+                               endOffset));
           httpConnection_->sendRequest(httpRequest);
         }
       }
