@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_LIBGCRYPT_ARC4_CONTEXT_H_
-#define _D_LIBGCRYPT_ARC4_CONTEXT_H_
+#ifndef D_LIBGCRYPT_ARC4_CONTEXT_H
+#define D_LIBGCRYPT_ARC4_CONTEXT_H
 
 #include "common.h"
 
@@ -46,7 +46,7 @@ namespace aria2 {
 
 class LibgcryptARC4Context {
 private:
-  gcry_cipher_hd_t _cipherCtx;
+  gcry_cipher_hd_t cipherCtx_;
 
   void handleError(gcry_error_t err) const
   {
@@ -55,39 +55,39 @@ private:
                     gcry_strerror(err)).str());
   }
 public:
-  LibgcryptARC4Context():_cipherCtx(0) {}
+  LibgcryptARC4Context():cipherCtx_(0) {}
 
   ~LibgcryptARC4Context()
   {
-    gcry_cipher_close(_cipherCtx);
+    gcry_cipher_close(cipherCtx_);
   }
 
   gcry_cipher_hd_t getCipherContext() const
   {
-    return _cipherCtx;
+    return cipherCtx_;
   }
 
   void init(const unsigned char* key, size_t keyLength)
   {
-    gcry_cipher_close(_cipherCtx);
+    gcry_cipher_close(cipherCtx_);
 
     int algo = GCRY_CIPHER_ARCFOUR;
     int mode = GCRY_CIPHER_MODE_STREAM;
     unsigned int flags = 0;
     {
-      gcry_error_t r = gcry_cipher_open(&_cipherCtx, algo, mode, flags);
+      gcry_error_t r = gcry_cipher_open(&cipherCtx_, algo, mode, flags);
       if(r) {
         handleError(r);
       }
     }
     {
-      gcry_error_t r = gcry_cipher_setkey(_cipherCtx, key, keyLength);
+      gcry_error_t r = gcry_cipher_setkey(cipherCtx_, key, keyLength);
       if(r) {
         handleError(r);
       }
     }
     {
-      gcry_error_t r = gcry_cipher_setiv(_cipherCtx, 0, 0);
+      gcry_error_t r = gcry_cipher_setiv(cipherCtx_, 0, 0);
       if(r) {
         handleError(r);
       }
@@ -97,4 +97,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_LIBGCRYPT_ARC4_CONTEXT_H_
+#endif // D_LIBGCRYPT_ARC4_CONTEXT_H
