@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_LIBGCRYPT_ARC4_ENCRYPTOR_H_
-#define _D_LIBGCRYPT_ARC4_ENCRYPTOR_H_
+#ifndef D_LIBGCRYPT_ARC4_ENCRYPTOR_H
+#define D_LIBGCRYPT_ARC4_ENCRYPTOR_H
 
 #include "common.h"
 
@@ -47,13 +47,13 @@ namespace aria2 {
 
 class ARC4Encryptor {
 private:
-  LibgcryptARC4Context _ctx;
+  LibgcryptARC4Context ctx_;
 
   void handleError(gcry_error_t err) const
   {
     throw DL_ABORT_EX
       (StringFormat("Exception in libgcrypt routine(ARC4Encryptor class): %s",
-		    gcry_strerror(err)).str());
+                    gcry_strerror(err)).str());
   }
 public:
   ARC4Encryptor() {}
@@ -62,14 +62,14 @@ public:
 
   void init(const unsigned char* key, size_t keyLength)
   {
-    _ctx.init(key, keyLength);
+    ctx_.init(key, keyLength);
   }
 
   void encrypt(unsigned char* out, size_t outLength,
-	       const unsigned char* in, size_t inLength)
+               const unsigned char* in, size_t inLength)
   {
-    gcry_error_t r = gcry_cipher_encrypt(_ctx.getCipherContext(),
-					 out, outLength, in, inLength);
+    gcry_error_t r = gcry_cipher_encrypt(ctx_.getCipherContext(),
+                                         out, outLength, in, inLength);
     if(r) {
       handleError(r);
     }
@@ -78,4 +78,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_LIBGCRYPT_ARC4_ENCRYPTOR_H_
+#endif // D_LIBGCRYPT_ARC4_ENCRYPTOR_H
