@@ -67,8 +67,9 @@
 namespace aria2 {
 
 Metalink2RequestGroup::Metalink2RequestGroup():
-  _logger(LogFactory::getInstance()) {}
+  logger_(LogFactory::getInstance()) {}
 
+namespace {
 class AccumulateNonP2PUri {
 private:
   std::vector<std::string>& urisPtr;
@@ -88,7 +89,9 @@ public:
     }
   }
 };
+} // namespace
 
+namespace {
 class FindBitTorrentUri {
 public:
   FindBitTorrentUri() {}
@@ -101,6 +104,7 @@ public:
     }
   }
 };
+} // namespace
 
 void
 Metalink2RequestGroup::generate
@@ -144,7 +148,7 @@ Metalink2RequestGroup::createRequestGroup
  const SharedHandle<Option>& option)
 {
   if(entries.empty()) {
-    _logger->notice(EX_NO_RESULT_WITH_YOUR_PREFS);
+    logger_->notice(EX_NO_RESULT_WITH_YOUR_PREFS);
     return;
   }
   std::vector<int32_t> selectIndexes =
@@ -193,7 +197,7 @@ Metalink2RequestGroup::createRequestGroup
         entryGroups.begin(), eoi = entryGroups.end(); itr != eoi; ++itr) {
     const std::string& metaurl = (*itr).first;
     const std::vector<SharedHandle<MetalinkEntry> >& mes = (*itr).second;
-    _logger->info("Processing metaurl group metaurl=%s", metaurl.c_str());
+    logger_->info("Processing metaurl group metaurl=%s", metaurl.c_str());
 #ifdef ENABLE_BITTORRENT
     SharedHandle<RequestGroup> torrentRg;
     if(!metaurl.empty()) {
@@ -229,7 +233,7 @@ Metalink2RequestGroup::createRequestGroup
     SharedHandle<DownloadContext> dctx;
     if(mes.size() == 1) {
       SharedHandle<MetalinkEntry> entry = mes[0];
-      _logger->info(MSG_METALINK_QUEUEING, entry->getPath().c_str());
+      logger_->info(MSG_METALINK_QUEUEING, entry->getPath().c_str());
       entry->reorderResourcesByPriority();
       std::vector<std::string> uris;
       std::for_each(entry->resources.begin(), entry->resources.end(),
@@ -252,8 +256,9 @@ Metalink2RequestGroup::createRequestGroup
                   util::applyDir(option->get(PREF_DIR),
                                  entry->file->getPath())));
       dctx->getFirstFileEntry()->setUris(uris);
+      dctx->getFirstFileEntry()->setMaxConnectionPerServer(1);
       if(option->getAsBool(PREF_METALINK_ENABLE_UNIQUE_PROTOCOL)) {
-        dctx->getFirstFileEntry()->disableSingleHostMultiConnection();
+        dctx->getFirstFileEntry()->setUniqueProtocol(true);
       }
 #ifdef ENABLE_MESSAGE_DIGEST
       if(!entry->checksum.isNull()) {
@@ -280,9 +285,9 @@ Metalink2RequestGroup::createRequestGroup
       off_t offset = 0;
       for(std::vector<SharedHandle<MetalinkEntry> >::const_iterator i =
             mes.begin(), eoi = mes.end(); i != eoi; ++i) {
-        _logger->info("Metalink: Queueing %s for download as a member.",
+        logger_->info("Metalink: Queueing %s for download as a member.",
                       (*i)->getPath().c_str());
-        _logger->debug("originalName = %s", (*i)->metaurls[0]->name.c_str());
+        logger_->debug("originalName = %s", (*i)->metaurls[0]->name.c_str());
         (*i)->reorderResourcesByPriority();
         std::vector<std::string> uris;
         std::for_each((*i)->resources.begin(), (*i)->resources.end(),
@@ -291,8 +296,9 @@ Metalink2RequestGroup::createRequestGroup
           (new FileEntry
            (util::applyDir(option->get(PREF_DIR), (*i)->file->getPath()),
             (*i)->file->getLength(), offset, uris));
+        fe->setMaxConnectionPerServer(1);
         if(option->getAsBool(PREF_METALINK_ENABLE_UNIQUE_PROTOCOL)) {
-          fe->disableSingleHostMultiConnection();
+          fe->setUniqueProtocol(true);
         }
         fe->setOriginalName((*i)->metaurls[0]->name);
         fileEntries.push_back(fe);
@@ -313,6 +319,25 @@ Metalink2RequestGroup::createRequestGroup
       SharedHandle<Dependency> dep(new BtDependency(rg, torrentRg));
       rg->dependsOn(dep);
       torrentRg->belongsTo(rg->getGID());
+      // metadata download may take very long time. If URIs are
+      // available, give up metadata download in at most 30 seconds.
+      const time_t btStopTimeout = 30;
+      time_t currentBtStopTimeout =
+        torrentRg->getOption()->getAsInt(PREF_BT_STOP_TIMEOUT);
+      if(currentBtStopTimeout == 0 || currentBtStopTimeout > btStopTimeout) {
+        std::vector<SharedHandle<FileEntry> >::const_iterator i;
+        std::vector<SharedHandle<FileEntry> >::const_iterator eoi
+          = dctx->getFileEntries().end();
+        for(i = dctx->getFileEntries().begin(); i != eoi; ++i) {
+          if((*i)->getRemainingUris().empty()) {
+            break;
+          }
+        }
+        if(i == dctx->getFileEntries().end()) {
+          torrentRg->getOption()->put
+            (PREF_BT_STOP_TIMEOUT, util::itos(btStopTimeout));
+        }
+      }
     }
 #endif // ENABLE_BITTORRENT
     groups.push_back(rg);
