@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_METALINK_ENTRY_H_
-#define _D_METALINK_ENTRY_H_
+#ifndef D_METALINK_ENTRY_H
+#define D_METALINK_ENTRY_H
 
 #include "common.h"
 
@@ -70,7 +70,7 @@ public:
   SharedHandle<ChunkChecksum> chunkChecksum;
 #endif // ENABLE_MESSAGE_DIGEST
 private:
-  SharedHandle<Signature> _signature;
+  SharedHandle<Signature> signature_;
 public:
   MetalinkEntry();
 
@@ -117,10 +117,10 @@ public:
 
   const SharedHandle<Signature>& getSignature() const
   {
-    return _signature;
+    return signature_;
   }
 };
 
 } // namespace aria2
 
-#endif // _D_METALINK_ENTRY_H_
+#endif // D_METALINK_ENTRY_H
