@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_METALINKER_H_
-#define _D_METALINKER_H_
+#ifndef D_METALINKER_H
+#define D_METALINKER_H
 
 #include "common.h"
 
@@ -47,15 +47,15 @@ namespace aria2 {
 class MetalinkEntry;
 
 class Metalinker {
-public:
-  std::vector<SharedHandle<MetalinkEntry> > entries;
+private:
+  std::vector<SharedHandle<MetalinkEntry> > entries_;
 public:
   Metalinker();
   ~Metalinker();
 
   Metalinker& operator=(const Metalinker& metalinker) {
     if(this != &metalinker) {
-      this->entries = metalinker.entries;
+      entries_ = metalinker.entries_;
     }
     return *this;
   }
@@ -65,8 +65,18 @@ public:
    const std::string& version,
    const std::string& language,
    const std::string& os) const;
+
+  const std::vector<SharedHandle<MetalinkEntry> >& getEntries() const
+  {
+    return entries_;
+  }
+
+  void addEntry(const SharedHandle<MetalinkEntry>& entry)
+  {
+    entries_.push_back(entry);
+  }
 };
 
 } // namespace aria2
 
-#endif // _D_METALINKER_H_
+#endif // D_METALINKER_H
