@@ -55,8 +55,9 @@ OptionParser::OptionParser():
   idCounter_(0)
 {}
 
+namespace {
 template<typename InputIterator>
-static size_t countPublicOption(InputIterator first, InputIterator last)
+size_t countPublicOption(InputIterator first, InputIterator last)
 {
   size_t count = 0;
   for(; first != last; ++first) {
@@ -66,10 +67,12 @@ static size_t countPublicOption(InputIterator first, InputIterator last)
   }
   return count;
 }
+} // namespace
 
+namespace {
 template<typename InputIterator>
-static void putOptions(struct option* longOpts, int* plopt,
-                       InputIterator first, InputIterator last)
+void putOptions(struct option* longOpts, int* plopt,
+                InputIterator first, InputIterator last)
 {
   for(; first != last; ++first) {
     if(!(*first)->isHidden()) {
@@ -106,9 +109,11 @@ static void putOptions(struct option* longOpts, int* plopt,
   (*longOpts).flag = 0;
   (*longOpts).val = 0;
 }
+} // namespace
 
+namespace {
 template<typename InputIterator>
-static std::string createOptstring(InputIterator first, InputIterator last)
+std::string createOptstring(InputIterator first, InputIterator last)
 {
   std::string str = "";
   for(; first != last; ++first) {
@@ -125,6 +130,7 @@ static std::string createOptstring(InputIterator first, InputIterator last)
   }
   return str;
 }
+} // namespace
 
 void OptionParser::parseArg
 (std::ostream& out, std::vector<std::string>& nonopts,
@@ -169,7 +175,8 @@ void OptionParser::parse(Option& option, std::istream& is)
     if(util::startsWith(line, A2STR::SHARP_C)) {
       continue;
     }
-    std::pair<std::string, std::string> nv = util::split(line, A2STR::EQUAL_C);
+    std::pair<std::string, std::string> nv;
+    util::divide(nv, line, '=');
     if(nv.first.empty()) {
       continue;
     }
@@ -190,7 +197,7 @@ public:
     return A2STR::NIL;
   }
 };
-}
+} // namespace
 
 OptionHandlerHandle OptionParser::getOptionHandlerByName
 (const std::string& optName)
@@ -254,7 +261,7 @@ public:
     return !optionHandler->isHidden() && optionHandler->hasTag(tag_);
   }
 };
-}
+} // namespace
 
 std::vector<SharedHandle<OptionHandler> >
 OptionParser::findByTag(const std::string& tag) const
@@ -282,7 +289,7 @@ public:
       optionHandler->getName().find(substring_) != std::string::npos;
   }
 };
-}
+} // namespace
 
 std::vector<SharedHandle<OptionHandler> >
 OptionParser::findByNameSubstring(const std::string& substring) const
@@ -305,8 +312,9 @@ std::vector<SharedHandle<OptionHandler> > OptionParser::findAll() const
   return result;
 }
 
+namespace {
 template<typename InputIterator, typename Predicate>
-static SharedHandle<OptionHandler> findOptionHandler
+SharedHandle<OptionHandler> findOptionHandler
 (InputIterator first, InputIterator last, Predicate pred)
 {
   SharedHandle<OptionHandler> handler;
@@ -316,6 +324,7 @@ static SharedHandle<OptionHandler> findOptionHandler
   }
   return handler;
 }
+} // namespace
 
 SharedHandle<OptionHandler>
 OptionParser::findByName(const std::string& name) const
@@ -346,7 +355,7 @@ public:
     return !optionHandler->isHidden() && optionHandler->getOptionID() == id_;
   }
 };
-}
+} // namespace
 
 SharedHandle<OptionHandler> OptionParser::findByID(int id) const
 {
@@ -368,7 +377,7 @@ public:
       optionHandler->getShortName() == shortName_;
   }
 };
-}
+} // namespace
 
 SharedHandle<OptionHandler> OptionParser::findByShortName(char shortName) const
 {
