@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_PEER_H_
-#define _D_PEER_H_
+#ifndef D_PEER_H
+#define D_PEER_H
 
 #include "common.h"
 
@@ -55,35 +55,38 @@ class PeerSessionResource;
 class BtMessageDispatcher;
 
 class Peer {
-public:
-  std::string ipaddr;
-  // TCP port of the other end of communication.  If _incoming is
+private:
+  std::string ipaddr_;
+  // TCP port of the other end of communication.  If incoming_ is
   // true, then this port is not a port the peer is listening to and
   // we cannot connect to it.
-  uint16_t port;
-private:
-  std::string id;
+  uint16_t port_;
 
-  cuid_t _cuid;
+  std::string id_;
 
-  unsigned char _peerId[PEER_ID_LENGTH];
+  cuid_t cuid_;
 
-  Timer _firstContactTime;
+  unsigned char peerId_[PEER_ID_LENGTH];
 
-  Timer _badConditionStartTime;
+  Timer firstContactTime_;
 
-  bool _seeder;
+  Timer badConditionStartTime_;
 
-  PeerSessionResource* _res;
+  bool seeder_;
+
+  PeerSessionResource* res_;
 
   // If true, port is assumed not to be a listening port.
-  bool _incoming;
+  bool incoming_;
 
   // If true, this peer is from local network.
-  bool _localPeer;
+  bool localPeer_;
+
+  // If true, this peer is disconnected gracefully.
+  bool disconnectedGracefully_;
 
   // Before calling updateSeeder(),  make sure that
-  // allocateSessionResource() is called and _res is created.
+  // allocateSessionResource() is called and res_ is created.
   // Otherwise assertion fails.
   void updateSeeder();
 public:
@@ -93,7 +96,7 @@ public:
 
   bool operator==(const Peer& p)
   {
-    return id == p.id;
+    return id_ == p.id_;
   }
   
   bool operator!=(const Peer& p)
@@ -103,39 +106,54 @@ public:
 
   void resetStatus();
 
+  const std::string& getIPAddress() const
+  {
+    return ipaddr_;
+  }
+
+  uint16_t getPort() const
+  {
+    return port_;
+  }
+
+  void setPort(uint16_t port)
+  {
+    port_ = port;
+  }
+
   void usedBy(cuid_t cuid);
 
   cuid_t usedBy() const
   {
-    return _cuid;
+    return cuid_;
   }
 
   bool unused() const
   {
-    return _cuid == 0;
+    return cuid_ == 0;
   }
 
-  // Returns true iff _res != 0.
+  // Returns true iff res_ != 0.
   bool isActive() const
   {
-    return _res != 0;
+    return res_ != 0;
   }
 
   void setPeerId(const unsigned char* peerId);
 
   const unsigned char* getPeerId() const
   {
-    return _peerId;
+    return peerId_;
   }
 
   bool isSeeder() const
   {
-    return _seeder;
+    return seeder_;
   }
 
   const std::string& getID() const
   {
-    return id;
+    return id_;
   }
 
   void startBadCondition();
@@ -144,22 +162,24 @@ public:
 
   void allocateSessionResource(size_t pieceLength, uint64_t totalLength);
 
+  void reconfigureSessionResource(size_t pieceLength, uint64_t totalLength);
+
   void releaseSessionResource();
 
   const Timer& getFirstContactTime() const
   {
-    return _firstContactTime;
+    return firstContactTime_;
   }
 
   void setFirstContactTime(const Timer& time);
 
   const Timer& getBadConditionStartTime() const
   {
-    return _badConditionStartTime;
+    return badConditionStartTime_;
   }
 
   // Before calling following member functions,  make sure that
-  // allocateSessionResource() is called and _res is created.
+  // allocateSessionResource() is called and res_ is created.
   // Otherwise assertion fails.
 
   // localhost is choking this peer
@@ -277,19 +297,29 @@ public:
 
   bool isIncomingPeer() const
   {
-    return _incoming;
+    return incoming_;
   }
 
   void setIncomingPeer(bool incoming);
 
   bool isLocalPeer() const
   {
-    return _localPeer;
+    return localPeer_;
   }
 
   void setLocalPeer(bool flag)
   {
-    _localPeer = flag;
+    localPeer_ = flag;
+  }
+
+  bool isDisconnectedGracefully() const
+  {
+    return disconnectedGracefully_;
+  }
+
+  void setDisconnectedGracefully(bool f)
+  {
+    disconnectedGracefully_ = f;
   }
 
   void setBtMessageDispatcher(const WeakHandle<BtMessageDispatcher>& dpt);
@@ -305,4 +335,4 @@ size_t countSeeder(InputIterator first, InputIterator last)
 
 } // namespace aria2
 
-#endif // _D_PEER_H_
+#endif // D_PEER_H
