@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_PEER_INTERACTION_COMMAND_H_
-#define _D_PEER_INTERACTION_COMMAND_H_
+#ifndef D_PEER_INTERACTION_COMMAND_H
+#define D_PEER_INTERACTION_COMMAND_H
 
 #include "PeerAbstractCommand.h"
 
@@ -55,16 +55,16 @@ public:
     RECEIVER_WAIT_HANDSHAKE,
     WIRED};
 private:
-  RequestGroup* _requestGroup;
+  RequestGroup* requestGroup_;
 
-  SharedHandle<BtRuntime> _btRuntime;
+  SharedHandle<BtRuntime> btRuntime_;
 
-  SharedHandle<PieceStorage> _pieceStorage;
+  SharedHandle<PieceStorage> pieceStorage_;
 
-  SharedHandle<PeerStorage> _peerStorage;
+  SharedHandle<PeerStorage> peerStorage_;
 
-  Seq sequence;
-  SharedHandle<BtInteractive> btInteractive;
+  Seq sequence_;
+  SharedHandle<BtInteractive> btInteractive_;
 
   const SharedHandle<Option>& getOption() const;
 protected:
@@ -91,4 +91,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_PEER_INTERACTION_COMMAND_H_
+#endif // D_PEER_INTERACTION_COMMAND_H
