@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_REQUEST_GROUP_H_
-#define _D_REQUEST_GROUP_H_
+#ifndef D_REQUEST_GROUP_H
+#define D_REQUEST_GROUP_H
 
 #include "common.h"
 
@@ -65,7 +65,7 @@ class Option;
 class Logger;
 class RequestGroup;
 class CheckIntegrityEntry;
-class DownloadResult;
+struct DownloadResult;
 class URISelector;
 class URIResult;
 class RequestGroupMan;
@@ -84,97 +84,99 @@ public:
     USER_REQUEST
   };
 private:
-  static gid_t _gidCounter;
+  static gid_t gidCounter_;
 
-  gid_t _gid;
+  gid_t gid_;
 
-  SharedHandle<Option> _option;
+  SharedHandle<Option> option_;
 
-  size_t _numConcurrentCommand;
+  size_t numConcurrentCommand_;
 
   /**
    * This is the number of connections used in streaming protocol(http/ftp)
    */
-  unsigned int _numStreamConnection;
+  unsigned int numStreamConnection_;
 
-  unsigned int _numCommand;
+  unsigned int numStreamCommand_;
 
-  SharedHandle<SegmentMan> _segmentMan;
+  unsigned int numCommand_;
 
-  SharedHandle<DownloadContext> _downloadContext;
+  SharedHandle<SegmentMan> segmentMan_;
 
-  SharedHandle<PieceStorage> _pieceStorage;
+  SharedHandle<DownloadContext> downloadContext_;
 
-  bool _saveControlFile;
+  SharedHandle<PieceStorage> pieceStorage_;
 
-  SharedHandle<BtProgressInfoFile> _progressInfoFile;
+  bool saveControlFile_;
 
-  SharedHandle<DiskWriterFactory> _diskWriterFactory;
+  SharedHandle<BtProgressInfoFile> progressInfoFile_;
 
-  SharedHandle<Dependency> _dependency;
+  SharedHandle<DiskWriterFactory> diskWriterFactory_;
 
-  bool _fileAllocationEnabled;
+  SharedHandle<Dependency> dependency_;
 
-  bool _preLocalFileCheckEnabled;
+  bool fileAllocationEnabled_;
 
-  bool _haltRequested;
+  bool preLocalFileCheckEnabled_;
 
-  bool _forceHaltRequested;
+  bool haltRequested_;
 
-  HaltReason _haltReason;
+  bool forceHaltRequested_;
 
-  bool _pauseRequested;
+  HaltReason haltReason_;
 
-  std::vector<SharedHandle<PreDownloadHandler> > _preDownloadHandlers;
+  bool pauseRequested_;
 
-  std::vector<SharedHandle<PostDownloadHandler> > _postDownloadHandlers;
+  std::vector<SharedHandle<PreDownloadHandler> > preDownloadHandlers_;
 
-  std::vector<std::string> _acceptTypes;
+  std::vector<SharedHandle<PostDownloadHandler> > postDownloadHandlers_;
 
-  SharedHandle<URISelector> _uriSelector;
+  std::vector<std::string> acceptTypes_;
 
-  Time _lastModifiedTime;
+  SharedHandle<URISelector> uriSelector_;
 
-  unsigned int _fileNotFoundCount;
+  Time lastModifiedTime_;
+
+  unsigned int fileNotFoundCount_;
 
   // Timeout used for HTTP/FTP downloads.
-  time_t _timeout;
+  time_t timeout_;
 
 #ifdef ENABLE_BITTORRENT
-  WeakHandle<BtRuntime> _btRuntime;
+  WeakHandle<BtRuntime> btRuntime_;
 
-  WeakHandle<PeerStorage> _peerStorage;
+  WeakHandle<PeerStorage> peerStorage_;
 #endif // ENABLE_BITTORRENT
 
   // This flag just indicates that the downloaded file is not saved disk but
   // just sits in memory.
-  bool _inMemoryDownload;
+  bool inMemoryDownload_;
 
-  unsigned int _maxDownloadSpeedLimit;
+  unsigned int maxDownloadSpeedLimit_;
 
-  unsigned int _maxUploadSpeedLimit;
+  unsigned int maxUploadSpeedLimit_;
 
-  SharedHandle<URIResult> _lastUriResult;
+  SharedHandle<URIResult> lastUriResult_;
 
   // If this download generates another downloads when completed(for
   // example, downloads generated by PostDownloadHandler), this field
   // has the GID of generated RequestGroups. empty list means there is
   // no such RequestGroup.
-  std::vector<gid_t> _followedByGIDs;
+  std::vector<gid_t> followedByGIDs_;
 
   // If this download is a part of another download(for example,
   // downloading torrent file described in Metalink file), this field
   // has the GID of parent RequestGroup. 0 means this is a parent
   // RequestGroup.
-  gid_t _belongsToGID;
+  gid_t belongsToGID_;
 
-  SharedHandle<MetadataInfo> _metadataInfo;
+  SharedHandle<MetadataInfo> metadataInfo_;
 
-  RequestGroupMan* _requestGroupMan;
+  RequestGroupMan* requestGroupMan_;
 
-  int _resumeFailureCount;
+  int resumeFailureCount_;
 
-  Logger* _logger;
+  Logger* logger_;
 
   void validateFilename(const std::string& expectedFilename,
                         const std::string& actualFilename) const;
@@ -194,6 +196,8 @@ private:
 
   void removeDefunctControlFile
   (const SharedHandle<BtProgressInfoFile>& progressInfoFile);
+
+  bool isCheckIntegrityReady() const;
 public:
   // The copy of option is stored in RequestGroup object.
   RequestGroup(const SharedHandle<Option>& option);
@@ -202,9 +206,11 @@ public:
 
   const SharedHandle<SegmentMan>& getSegmentMan() const
   {
-    return _segmentMan;
+    return segmentMan_;
   }
 
+  SharedHandle<CheckIntegrityEntry> createCheckIntegrityEntry();
+
   // Returns first bootstrap commands to initiate a download.
   // If this is HTTP/FTP download and file size is unknown, only 1 command
   // (usually, HttpInitiateConnection or FtpInitiateConnection) will be created.
@@ -245,24 +251,24 @@ public:
 
   void setNumConcurrentCommand(unsigned int num)
   {
-    _numConcurrentCommand = num;
+    numConcurrentCommand_ = num;
   }
 
   unsigned int getNumConcurrentCommand() const
   {
-    return _numConcurrentCommand;
+    return numConcurrentCommand_;
   }
 
   gid_t getGID() const
   {
-    return _gid;
+    return gid_;
   }
 
   TransferStat calculateStat() const;
 
   const SharedHandle<DownloadContext>& getDownloadContext() const
   {
-    return _downloadContext;
+    return downloadContext_;
   }
 
   // This function also calls
@@ -271,20 +277,21 @@ public:
 
   const SharedHandle<PieceStorage>& getPieceStorage() const
   {
-    return _pieceStorage;
+    return pieceStorage_;
   }
 
   void setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage);
 
   void setProgressInfoFile(const SharedHandle<BtProgressInfoFile>& progressInfoFile);
 
+  void increaseStreamCommand();
+
+  void decreaseStreamCommand();
+
   void increaseStreamConnection();
 
   void decreaseStreamConnection();
 
-  // Returns the number of connections used in HTTP(S)/FTP.
-  unsigned int getNumStreamConnection() { return _numStreamConnection; }
-
   unsigned int getNumConnection() const;
 
   void increaseNumCommand();
@@ -293,7 +300,7 @@ public:
 
   unsigned int getNumCommand() const
   {
-    return _numCommand;
+    return numCommand_;
   }
 
   // TODO is it better to move the following 2 methods to SingleFileDownloadContext?
@@ -301,34 +308,34 @@ public:
 
   const SharedHandle<DiskWriterFactory>& getDiskWriterFactory() const
   {
-    return _diskWriterFactory;
+    return diskWriterFactory_;
   }
 
   void setFileAllocationEnabled(bool f)
   {
-    _fileAllocationEnabled = f;
+    fileAllocationEnabled_ = f;
   }
 
   bool isFileAllocationEnabled() const
   {
-    return _fileAllocationEnabled;
+    return fileAllocationEnabled_;
   }
 
   bool needsFileAllocation() const;
 
   /**
-   * Setting _preLocalFileCheckEnabled to false, then skip the check to see
+   * Setting preLocalFileCheckEnabled_ to false, then skip the check to see
    * if a file is already exists and control file exists etc.
    * Always open file with DiskAdaptor::initAndOpenFile()
    */
   void setPreLocalFileCheckEnabled(bool f)
   {
-    _preLocalFileCheckEnabled = f;
+    preLocalFileCheckEnabled_ = f;
   }
 
   bool isPreLocalFileCheckEnabled() const
   {
-    return _preLocalFileCheckEnabled;
+    return preLocalFileCheckEnabled_;
   }
 
   void setHaltRequested(bool f, HaltReason = SHUTDOWN_SIGNAL);
@@ -337,19 +344,19 @@ public:
 
   bool isHaltRequested() const
   {
-    return _haltRequested;
+    return haltRequested_;
   }
 
   bool isForceHaltRequested() const
   {
-    return _forceHaltRequested;
+    return forceHaltRequested_;
   }
 
   void setPauseRequested(bool f);
 
   bool isPauseRequested() const
   {
-    return _pauseRequested;
+    return pauseRequested_;
   }
 
   void dependsOn(const SharedHandle<Dependency>& dep);
@@ -374,8 +381,8 @@ public:
                                   const SharedHandle<CheckIntegrityEntry>& entry,
                                   DownloadEngine* e);
 
-  // Initializes _pieceStorage and _segmentMan.  We guarantee that
-  // either both of _pieceStorage and _segmentMan are initialized or
+  // Initializes pieceStorage_ and segmentMan_.  We guarantee that
+  // either both of pieceStorage_ and segmentMan_ are initialized or
   // they are not.
   void initPieceStorage();
 
@@ -393,14 +400,14 @@ public:
 
   const SharedHandle<Option>& getOption() const
   {
-    return _option;
+    return option_;
   }
 
   void reportDownloadFinished();
 
   const std::vector<std::string>& getAcceptTypes() const
   {
-    return _acceptTypes;
+    return acceptTypes_;
   }
 
   void addAcceptType(const std::string& type);
@@ -409,9 +416,9 @@ public:
   void addAcceptType(InputIterator first, InputIterator last)
   {
     for(; first != last; ++first) {
-      if(std::find(_acceptTypes.begin(), _acceptTypes.end(), *first) ==
-	 _acceptTypes.end()) {
-	_acceptTypes.push_back(*first);
+      if(std::find(acceptTypes_.begin(), acceptTypes_.end(), *first) ==
+	 acceptTypes_.end()) {
+	acceptTypes_.push_back(*first);
       }
     }
   }
@@ -422,7 +429,7 @@ public:
 
   const SharedHandle<URISelector>& getURISelector() const
   {
-    return _uriSelector;
+    return uriSelector_;
   }
 
   void applyLastModifiedTimeToLocalFiles();
@@ -437,44 +444,44 @@ public:
   // Returns inMemoryDownload flag.
   bool inMemoryDownload() const
   {
-    return _inMemoryDownload;
+    return inMemoryDownload_;
   }
 
   void setTimeout(time_t timeout);
 
   time_t getTimeout() const
   {
-    return _timeout;
+    return timeout_;
   }
 
   // Returns true if current download speed exceeds
-  // _maxDownloadSpeedLimit.  Always returns false if
-  // _maxDownloadSpeedLimit == 0.  Otherwise returns false.
+  // maxDownloadSpeedLimit_.  Always returns false if
+  // maxDownloadSpeedLimit_ == 0.  Otherwise returns false.
   bool doesDownloadSpeedExceed();
 
   // Returns true if current upload speed exceeds
-  // _maxUploadSpeedLimit. Always returns false if
-  // _maxUploadSpeedLimit == 0. Otherwise returns false.
+  // maxUploadSpeedLimit_. Always returns false if
+  // maxUploadSpeedLimit_ == 0. Otherwise returns false.
   bool doesUploadSpeedExceed();
 
   unsigned int getMaxDownloadSpeedLimit() const
   {
-    return _maxDownloadSpeedLimit;
+    return maxDownloadSpeedLimit_;
   }
 
   void setMaxDownloadSpeedLimit(unsigned int speed)
   {
-    _maxDownloadSpeedLimit = speed;
+    maxDownloadSpeedLimit_ = speed;
   }
 
   unsigned int getMaxUploadSpeedLimit() const
   {
-    return _maxUploadSpeedLimit;
+    return maxUploadSpeedLimit_;
   }
 
   void setMaxUploadSpeedLimit(unsigned int speed)
   {
-    _maxUploadSpeedLimit = speed;
+    maxUploadSpeedLimit_ = speed;
   }
 
   void setLastUriResult(std::string uri, downloadresultcode::RESULT result);
@@ -483,66 +490,66 @@ public:
 
   void removeControlFile() const;
 
-  void enableSaveControlFile() { _saveControlFile = true; }
+  void enableSaveControlFile() { saveControlFile_ = true; }
 
-  void disableSaveControlFile() { _saveControlFile = false; }
+  void disableSaveControlFile() { saveControlFile_ = false; }
 
   template<typename InputIterator>
   void followedBy(InputIterator groupFirst, InputIterator groupLast)
   {
-    _followedByGIDs.clear();
+    followedByGIDs_.clear();
     for(; groupFirst != groupLast; ++groupFirst) {
-      _followedByGIDs.push_back((*groupFirst)->getGID());
+      followedByGIDs_.push_back((*groupFirst)->getGID());
     }
   }
 
   const std::vector<gid_t>& followedBy() const
   {
-    return _followedByGIDs;
+    return followedByGIDs_;
   }
 
   void belongsTo(gid_t gid)
   {
-    _belongsToGID = gid;
+    belongsToGID_ = gid;
   }
 
   gid_t belongsTo() const
   {
-    return _belongsToGID;
+    return belongsToGID_;
   }
 
   void setRequestGroupMan(RequestGroupMan* requestGroupMan)
   {
-    _requestGroupMan = requestGroupMan;
+    requestGroupMan_ = requestGroupMan;
   }
 
   int getResumeFailureCount() const
   {
-    return _resumeFailureCount;
+    return resumeFailureCount_;
   }
 
   void increaseResumeFailureCount()
   {
-    ++_resumeFailureCount;
+    ++resumeFailureCount_;
   }
 
   bool p2pInvolved() const;
 
   void setMetadataInfo(const SharedHandle<MetadataInfo>& info)
   {
-    _metadataInfo = info;
+    metadataInfo_ = info;
   }
 
   const SharedHandle<MetadataInfo>& getMetadataInfo() const
   {
-    return _metadataInfo;
+    return metadataInfo_;
   }
 
-  static void resetGIDCounter() { _gidCounter = 0; }
+  static void resetGIDCounter() { gidCounter_ = 0; }
 
   static gid_t newGID();
 };
 
 } // namespace aria2
 
-#endif // _D_REQUEST_GROUP_H_
+#endif // D_REQUEST_GROUP_H
