@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_SERVER_STAT_H_
-#define _D_SERVER_STAT_H_
+#ifndef D_SERVER_STAT_H
+#define D_SERVER_STAT_H
 #include "common.h"
 
 #include <string>
@@ -173,4 +173,4 @@ std::ostream& operator<<(std::ostream& o, const ServerStat& serverStat);
 
 } // namespace aria2
 
-#endif // _D_SERVER_STAT_H_
+#endif // D_SERVER_STAT_H
