@@ -32,20 +32,18 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_SOCKET_CORE_H_
-#define _D_SOCKET_CORE_H_
+#ifndef D_SOCKET_CORE_H
+#define D_SOCKET_CORE_H
 
 #include "common.h"
 
-#ifdef HAVE_EPOLL
-# include <sys/epoll.h>
-#endif // HAVE_EPOLL
-
 #include <string>
 #include <cstdlib>
 #include <utility>
 #include <vector>
 
+#include "a2netcompat.h"
+
 #ifdef HAVE_LIBSSL
 // for SSL
 # include <openssl/ssl.h>
@@ -72,37 +70,22 @@ class SocketCore {
   friend bool operator<(const SocketCore& s1, const SocketCore& s2);
 private:
   // socket type defined in <sys/socket.h>
-  int _sockType;
+  int sockType_;
   // socket endpoint descriptor
-  sock_t sockfd;
+  sock_t sockfd_;
 
-#ifdef HAVE_EPOLL
+  static int protocolFamily_;
 
-  // file descriptor used for epoll
-  int _epfd;
+  static std::vector<std::pair<struct sockaddr_storage, socklen_t> > bindAddrs_;
 
-  struct epoll_event _epEvent;
+  bool blocking_;
+  int secure_;
 
-#endif // HAVE_EPOLL
-
-  enum PollMethod {
-    POLL_METHOD_EPOLL, POLL_METHOD_SELECT
-  };
-
-  static PollMethod _pollMethod;
-
-  static int _protocolFamily;
-
-  static std::vector<std::pair<struct sockaddr_storage, socklen_t> > _bindAddrs;
-
-  bool blocking;
-  int secure;
-
-  bool _wantRead;
-  bool _wantWrite;
+  bool wantRead_;
+  bool wantWrite_;
 
 #if ENABLE_SSL
-  static SharedHandle<TLSContext> _tlsContext;
+  static SharedHandle<TLSContext> tlsContext_;
 #endif // ENABLE_SSL
 
 #ifdef HAVE_LIBSSL
@@ -112,10 +95,10 @@ private:
   int sslHandleEAGAIN(int ret);
 #endif // HAVE_LIBSSL
 #ifdef HAVE_LIBGNUTLS
-  gnutls_session_t sslSession;
-  char* peekBuf;
-  size_t peekBufLength;
-  size_t peekBufMax;
+  gnutls_session_t sslSession_;
+  char* peekBuf_;
+  size_t peekBufLength_;
+  size_t peekBufMax_;
 
   size_t shiftPeekData(char* data, size_t len);
   void addPeekData(char* data, size_t len);
@@ -129,12 +112,6 @@ private:
 
   void bind(const struct sockaddr* addr, socklen_t addrlen);
 
-#ifdef HAVE_EPOLL
-
-  void initEPOLL();
-
-#endif // HAVE_EPOLL
-
   void setSockOpt(int level, int optname, void* optval, socklen_t optlen);
 
   SocketCore(sock_t sockfd, int sockType);
@@ -142,9 +119,9 @@ public:
   SocketCore(int sockType = SOCK_STREAM);
   ~SocketCore();
 
-  sock_t getSockfd() const { return sockfd; }
+  sock_t getSockfd() const { return sockfd_; }
 
-  bool isOpen() const { return sockfd != (sock_t) -1; }
+  bool isOpen() const { return sockfd_ != (sock_t) -1; }
 
   void setMulticastInterface(const std::string& localAddr);
 
@@ -160,8 +137,6 @@ public:
 
   void bindWithFamily(uint16_t port, int family, int flags = AI_PASSIVE);
 
-  void bind(const std::string& addr, uint16_t port, int flags = AI_PASSIVE);
-
   /**
    * Creates a socket and bind it with locahost's address and port.
    * flags is set to struct addrinfo's ai_flags.
@@ -170,6 +145,9 @@ public:
    */
   void bind(uint16_t port, int flags = AI_PASSIVE);
 
+  void bind
+  (const std::string& addr, uint16_t port, int family, int flags = AI_PASSIVE);
+
   /**
    * Listens form connection on it.
    * Call bind(uint16_t) before calling this function.
@@ -182,6 +160,21 @@ public:
    */
   void getAddrInfo(std::pair<std::string, uint16_t>& addrinfo) const;
 
+  /**
+   * Stores address of this socket to sockaddr.  len must be
+   * initialized to the size of sockaddr.  On success, address data is
+   * stored in sockaddr and actual size of address structure is stored
+   * in len.
+   */
+  void getAddrInfo
+  (struct sockaddr_storage& sockaddr, socklen_t& len) const;
+
+  /**
+   * Returns address family of this socket.
+   * The socket must be connected or bounded to address.
+   */
+  int getAddressFamily() const;
+
   /**
    * Stores peer's address and port to peerinfo.
    * @param peerinfo placeholder to store peer's address and port.
@@ -242,8 +235,8 @@ public:
    * all data is sent.
    * If the underlying socket is in non-blocking mode, this method may return
    * even if all data is sent. The size of written data is returned. If
-   * underlying socket gets EAGAIN, _wantRead or _wantWrite is set accordingly.
-   * This method sets _wantRead and _wantWrite to false before do anything else.
+   * underlying socket gets EAGAIN, wantRead_ or wantWrite_ is set accordingly.
+   * This method sets wantRead_ and wantWrite_ to false before do anything else.
    * @param data data to write
    * @param len length of data
    */
@@ -277,8 +270,8 @@ public:
    * at least 1byte is received.
    * If the underlying socket is in non-blocking mode, this method may return
    * even if no single byte is received. If the underlying socket gets EAGAIN,
-   * _wantRead or _wantWrite is set accordingly.
-   * This method sets _wantRead and _wantWrite to false before do anything else.
+   * wantRead_ or wantWrite_ is set accordingly.
+   * This method sets wantRead_ and wantWrite_ to false before do anything else.
    * @param data holder to store data.
    * @param len the maximum size data can store. This method assigns
    * the number of bytes read to len.
@@ -329,7 +322,7 @@ public:
   void prepareSecureConnection();
 
   bool operator==(const SocketCore& s) {
-    return sockfd == s.sockfd;
+    return sockfd_ == s.sockfd_;
   }
 
   bool operator!=(const SocketCore& s) {
@@ -337,7 +330,7 @@ public:
   }
 
   bool operator<(const SocketCore& s) {
-    return sockfd < s.sockfd;
+    return sockfd_ < s.sockfd_;
   }
 
   std::string getSocketError() const;
@@ -355,24 +348,19 @@ public:
    */
   bool wantWrite() const;
 
-#ifdef HAVE_EPOLL
-  static void useEpoll();
-#endif // HAVE_EPOLL
-  static void useSelect();
-
 #ifdef ENABLE_SSL
   static void setTLSContext(const SharedHandle<TLSContext>& tlsContext);
 #endif // ENABLE_SSL
 
   static void setProtocolFamily(int protocolFamily)
   {
-    _protocolFamily = protocolFamily;
+    protocolFamily_ = protocolFamily;
   }
 
   // Bind socket to interface. interface may be specified as a
   // hostname, IP address or interface name like eth0.  If the given
   // interface is not found or binding socket is failed, exception
-  // will be thrown.  Set _protocolFamily before calling this function
+  // will be thrown.  Set protocolFamily_ before calling this function
   // if you limit protocol family.
   //
   // We cannot use interface as an argument because it is a reserved
@@ -407,4 +395,4 @@ void getInterfaceAddress
 
 } // namespace aria2
 
-#endif // _D_SOCKET_CORE_H_
+#endif // D_SOCKET_CORE_H
