@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_UNKNOWN_LENGTH_PIECE_STORAGE_H_
-#define _D_UNKNOWN_LENGTH_PIECE_STORAGE_H_
+#ifndef D_UNKNOWN_LENGTH_PIECE_STORAGE_H
+#define D_UNKNOWN_LENGTH_PIECE_STORAGE_H
 
 #include "PieceStorage.h"
 
@@ -46,19 +46,19 @@ class DirectDiskAdaptor;
 
 class UnknownLengthPieceStorage:public PieceStorage {
 private:
-  SharedHandle<DownloadContext> _downloadContext;
+  SharedHandle<DownloadContext> downloadContext_;
 
-  const Option* _option;
+  const Option* option_;
   
-  SharedHandle<DirectDiskAdaptor> _diskAdaptor;
+  SharedHandle<DirectDiskAdaptor> diskAdaptor_;
 
-  SharedHandle<DiskWriterFactory> _diskWriterFactory;
+  SharedHandle<DiskWriterFactory> diskWriterFactory_;
 
-  uint64_t _totalLength;
+  uint64_t totalLength_;
 
-  bool _downloadFinished;
+  bool downloadFinished_;
 
-  SharedHandle<Piece> _piece;
+  SharedHandle<Piece> piece_;
 public:
   UnknownLengthPieceStorage(const SharedHandle<DownloadContext>& downloadContext,
                             const Option* option);
@@ -73,29 +73,32 @@ public:
    */
   virtual bool hasMissingPiece(const SharedHandle<Peer>& peer);
 
-  /**
-   * Returns a piece that the peer has but localhost doesn't.
-   * The piece will be marked "used" status in order to prevent other command
-   * from get the same piece. But in end game mode, same piece may be returned
-   * to several commands.
-   */
+  virtual void getMissingPiece
+  (std::vector<SharedHandle<Piece> >& pieces,
+   size_t minMissingBlocks,
+   const SharedHandle<Peer>& peer);
+
+  virtual void getMissingPiece
+  (std::vector<SharedHandle<Piece> >& pieces,
+   size_t minMissingBlocks,
+   const SharedHandle<Peer>& peer,
+   const std::vector<size_t>& excludedIndexes);
+
+  virtual void getMissingFastPiece
+  (std::vector<SharedHandle<Piece> >& pieces,
+   size_t minMissingBlocks,
+   const SharedHandle<Peer>& peer);
+
+  virtual void getMissingFastPiece
+  (std::vector<SharedHandle<Piece> >& pieces,
+   size_t minMissingBlocks,
+   const SharedHandle<Peer>& peer,
+   const std::vector<size_t>& excludedIndexes);
+
   virtual SharedHandle<Piece> getMissingPiece(const SharedHandle<Peer>& peer);
 
   virtual SharedHandle<Piece> getMissingPiece
   (const SharedHandle<Peer>& peer, const std::vector<size_t>& excludedIndexes);
-
-  /**
-   * Returns a piece that the peer has but localhost doesn't.
-   * Only pieces that declared as "fast" are returned.
-   * The piece will be marked "used" status in order to prevent other command
-   * from get the same piece. But in end game mode, same piece may be returned
-   * to several commands.
-   */
-  virtual SharedHandle<Piece> getMissingFastPiece(const SharedHandle<Peer>& peer);
-
-  virtual SharedHandle<Piece> getMissingFastPiece
-  (const SharedHandle<Peer>& peer, const std::vector<size_t>& excludedIndexes);
-
 #endif // ENABLE_BITTORRENT
 
   virtual bool hasMissingUnusedPiece();
@@ -104,7 +107,7 @@ public:
    * Returns a missing piece if available. Otherwise returns 0;
    */
   virtual SharedHandle<Piece> getSparseMissingUnusedPiece
-  (const unsigned char* ignoreBitfield, size_t length);
+  (size_t minSplitSize, const unsigned char* ignoreBitfield, size_t length);
 
   /**
    * Returns a missing piece whose index is index.
@@ -140,18 +143,18 @@ public:
 
   virtual uint64_t getTotalLength()
   {
-    return _totalLength;
+    return totalLength_;
   }
 
   virtual uint64_t getFilteredTotalLength()
   {
-    return _totalLength;
+    return totalLength_;
   }
 
   virtual uint64_t getCompletedLength()
   {
     // TODO we have to return actual completed length here?
-    return _totalLength;
+    return totalLength_;
   }
 
   virtual uint64_t getFilteredCompletedLength()
@@ -170,7 +173,7 @@ public:
    */
   virtual bool downloadFinished()
   {
-    return _downloadFinished;
+    return downloadFinished_;
   }
 
   /**
@@ -211,6 +214,8 @@ public:
     return false;
   }
 
+  virtual void enterEndGame() {}
+
   virtual void setEndGamePieceNum(size_t num) {}
 
   virtual SharedHandle<DiskAdaptor> getDiskAdaptor();
@@ -273,6 +278,7 @@ public:
                                 size_t newBitfieldLength,
                                 const unsigned char* oldBitfield) {}
 
+  virtual size_t getNextUsedIndex(size_t index) { return 0; }
 
   void setDiskWriterFactory(const SharedHandle<DiskWriterFactory>& diskWriterFactory);
 };
@@ -281,4 +287,4 @@ typedef SharedHandle<UnknownLengthPieceStorage> UnknownLengthPieceStorageHandle;
 
 } // namespace aria2
 
-#endif // _D_UNKNOWN_LENGTH_PIECE_STORAGE_H_
+#endif // D_UNKNOWN_LENGTH_PIECE_STORAGE_H
